# Python WordPress Tool
    A collection of tools for managing WordPress installations

## PhpVariableExtractor

### Extractor
    Class to extract variables from a PHP file as key value pairs in a Python dict.
  
  